@@ -45,7 +45,8 @@ test_succeeds("Can run build(hp) and plot_tuner()", {
                                          step = 32),input_shape = ncol(x_data),
                             activation = hp$Choice(paste('act_',i, sep = ''), c('relu', 'tanh'))) %>% 
         layer_dense(units = 1, activation='softmax')
-    } %>% 
+    } 
+    model %>% 
       compile(
         optimizer = tf$keras$optimizers$Adam(
           hp$Choice('learning_rate',
@@ -69,24 +70,17 @@ test_succeeds("Can run build(hp) and plot_tuner()", {
   
   if (!Sys.info()[1] %in% 'Windows') {
     
-    if (tensorflow::tf_version() == c('2.0') | tensorflow::tf_version() == c('2.1')) {
-      
-      tensorboardd = TensorBoard()
-      
-      tuner2 %>% fit_tuner(x_data, y_data, epochs = 5, validation_data = list(x_data2,y_data2), callbacks=list(tensorboardd))
-      
+      tuner2 %>% fit_tuner(x_data, y_data, epochs = 5, validation_data = list(x_data2,y_data2)#, callbacks=list(tensorboardd)
+      )
       res = tuner2 %>% get_best_models(1) %>% .[[1]] %>% capture.output() %>% .[1]
       
       testthat::expect_output(print(res),regexp ='Model')
       
       tuner2 %>% results_summary(12)
       
-      p1=kerastuneR::plot_tuner(tuner2, type = 'echarts4r')
-      p2=kerastuneR::plot_tuner(tuner2,height = 500, width = 500)
-      
       extract_model = tuner2 %>% get_best_models(1) %>% .[[1]]
-      
-    }
+    
+      tuner2 %>% plot_tuner()
     
   }
 })
