@@ -9,15 +9,14 @@ test_succeeds("Can run hyper_class", {
   
   cifar <- dataset_cifar10()
   
-  hypermodel = kerastuneR::HyperResNet(input_shape = list(300L, 300L, 3L), classes = 10L)
-  hypermodel2 = kerastuneR::HyperXception(input_shape = list(300L, 300L, 3L), classes = 10L)
+  hypermodel = HyperResNet(input_shape = list(300L, 300L, 3L), classes = 10L)
+  hypermodel2 = HyperXception(input_shape = list(300L, 300L, 3L), classes = 10L)
   
   testthat::expect_match(hypermodel %>% capture.output(),'kerastuner.applications.resnet.HyperResNet')
   
-  tuner = kerastuneR::Hyperband(
+  tuner = Hyperband(
     hypermodel = hypermodel,
-    objective = 'accuracy',
-    loss = 'sparse_categorical_crossentropy',
+    objective = 'val_accuracy',
     max_epochs = 1,
     directory = 'my_dir',
     project_name='helloworld')
@@ -36,6 +35,7 @@ test_succeeds("Can run hyper_class", {
     #tuner %>%  fit_tuner(x = tf$image$resize(train_data, size = shape(300, 300)), y = test_data, epochs = 1)
     print('Done')
   } else {
+    #tuner %>%  fit_tuner(x = tf$image$resize(train_data, size = shape(300, 300)), y = test_data, epochs = 1)
     print('Done')
   }
 })
